/**
 * DevExtreme (cjs/__internal/core/utils/m_locker.js)
 * Version: 24.2.2-beta
 * Build date: Mon Nov 18 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.Locker = void 0;
var _errors = _interopRequireDefault(require("../../../core/errors"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
const Locker = function() {
    const info = {};
    const currentCount = function(lockName) {
        return info[lockName] || 0
    };
    return {
        obtain(lockName) {
            info[lockName] = currentCount(lockName) + 1
        },
        release(lockName) {
            const count = currentCount(lockName);
            if (count < 1) {
                throw _errors.default.Error("E0014")
            }
            if (1 === count) {
                delete info[lockName]
            } else {
                info[lockName] = count - 1
            }
        },
        locked: lockName => currentCount(lockName) > 0
    }
};
exports.Locker = Locker;
