/**
 * DevExtreme (cjs/__internal/pagination/wrappers/pagination_wrapper.js)
 * Version: 24.2.2-beta
 * Build date: Mon Nov 18 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.PaginationWrapper = void 0;
var _component_wrapper = require("../../core/r1/component_wrapper");
var _validation_utils = require("../utils/validation_utils");
const _excluded = ["pageSize", "pageIndex", "itemCount"];

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}
class PaginationWrapper extends _component_wrapper.ComponentWrapper {
    _optionChanged(args) {
        switch (args.name) {
            case "pageIndex": {
                const pageIndexChanged = this.option("pageIndexChanged");
                if (pageIndexChanged) {
                    pageIndexChanged(args.value)
                }
                break
            }
            case "pageSize": {
                const pageSizeChanged = this.option("pageSizeChanged");
                if (pageSizeChanged) {
                    pageSizeChanged(args.value)
                }
                break
            }
        }
        super._optionChanged(args)
    }
    getPageCount() {
        return this.option("pageCount")
    }
    _validateOptions(options) {
        if (options._skipValidation || this.option("_skipValidation")) {
            return options
        }
        const initialOptions = super._validateOptions(options);
        let {
            pageSize: pageSize,
            pageIndex: pageIndex,
            itemCount: itemCount
        } = initialOptions, rest = _objectWithoutPropertiesLoose(initialOptions, _excluded);
        if (void 0 === pageSize) {
            pageSize = this.option("pageSize")
        }
        if (void 0 === pageIndex) {
            pageIndex = this.option("pageIndex")
        }
        if (void 0 === itemCount) {
            itemCount = this.option("itemCount")
        }
        const validatedOptions = (0, _validation_utils.validateOptions)(pageSize, pageIndex, itemCount);
        return _extends({}, rest, validatedOptions)
    }
}
exports.PaginationWrapper = PaginationWrapper;
