/**
 * DevExtreme (cjs/__internal/ui/chat/alertlist.js)
 * Version: 24.2.2-beta
 * Build date: Mon Nov 18 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = void 0;
var _renderer = _interopRequireDefault(require("../../../core/renderer"));
var _message = _interopRequireDefault(require("../../../localization/message"));
var _widget = _interopRequireDefault(require("../../core/widget/widget"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
const CHAT_ALERTLIST_CLASS = "dx-chat-alertlist";
const CHAT_ALERTLIST_ERROR_CLASS = "dx-chat-alertlist-error";
const CHAT_ALERTLIST_ERROR_ICON_CLASS = "dx-chat-alertlist-error-icon";
const CHAT_ALERTLIST_ERROR_TEXT_CLASS = "dx-chat-alertlist-error-text";
class AlertList extends _widget.default {
    _getDefaultOptions() {
        return _extends({}, super._getDefaultOptions(), {
            items: []
        })
    }
    _initMarkup() {
        (0, _renderer.default)(this.element()).addClass("dx-chat-alertlist");
        super._initMarkup();
        const {
            items: items
        } = this.option();
        this._renderItems(items);
        this._updateAria()
    }
    _renderItems(items) {
        if (null !== items && void 0 !== items && items.length) {
            items.forEach((itemData => {
                this._renderItem(itemData)
            }))
        }
    }
    _renderItem(itemData) {
        const $item = (0, _renderer.default)("<div>");
        $item.addClass("dx-chat-alertlist-error");
        (0, _renderer.default)("<div>").addClass("dx-chat-alertlist-error-icon").appendTo($item);
        (0, _renderer.default)("<div>").addClass("dx-chat-alertlist-error-text").appendTo($item).text(String((null === itemData || void 0 === itemData ? void 0 : itemData.message) ?? ""));
        $item.appendTo(this.$element())
    }
    _updateAria() {
        const aria = {
            role: "log",
            atomic: "false",
            label: _message.default.format("dxChat-alertListAriaLabel"),
            live: "polite",
            relevant: "additions"
        };
        this.setAria(aria)
    }
    _optionChanged(args) {
        const {
            name: name
        } = args;
        if ("items" === name) {
            this._invalidate()
        } else {
            super._optionChanged(args)
        }
    }
}
var _default = exports.default = AlertList;
