/**
 * DevExtreme (cjs/__internal/ui/chat/messagebox.js)
 * Version: 24.2.2-beta
 * Build date: Mon Nov 18 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = exports.TYPING_END_DELAY = void 0;
var _renderer = _interopRequireDefault(require("../../../core/renderer"));
var _message = _interopRequireDefault(require("../../../localization/message"));
var _button = _interopRequireDefault(require("../../../ui/button"));
var _dom_component = _interopRequireDefault(require("../../core/widget/dom_component"));
var _m_text_area = _interopRequireDefault(require("../m_text_area"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
const CHAT_MESSAGEBOX_CLASS = "dx-chat-messagebox";
const CHAT_MESSAGEBOX_TEXTAREA_CLASS = "dx-chat-messagebox-textarea";
const CHAT_MESSAGEBOX_BUTTON_CLASS = "dx-chat-messagebox-button";
const TYPING_END_DELAY = exports.TYPING_END_DELAY = 2e3;
class MessageBox extends _dom_component.default {
    _getDefaultOptions() {
        return _extends({}, super._getDefaultOptions(), {
            activeStateEnabled: true,
            focusStateEnabled: true,
            hoverStateEnabled: true,
            onMessageEntered: void 0,
            onTypingStart: void 0,
            onTypingEnd: void 0
        })
    }
    _init() {
        super._init();
        this._createMessageEnteredAction();
        this._createTypingStartAction();
        this._createTypingEndAction()
    }
    _initMarkup() {
        (0, _renderer.default)(this.element()).addClass("dx-chat-messagebox");
        super._initMarkup();
        this._renderTextArea();
        this._renderButton()
    }
    _renderTextArea() {
        const {
            activeStateEnabled: activeStateEnabled,
            focusStateEnabled: focusStateEnabled,
            hoverStateEnabled: hoverStateEnabled
        } = this.option();
        const $textArea = (0, _renderer.default)("<div>").addClass("dx-chat-messagebox-textarea").appendTo(this.element());
        this._textArea = this._createComponent($textArea, _m_text_area.default, {
            activeStateEnabled: activeStateEnabled,
            focusStateEnabled: focusStateEnabled,
            hoverStateEnabled: hoverStateEnabled,
            stylingMode: "outlined",
            placeholder: _message.default.format("dxChat-textareaPlaceholder"),
            autoResizeEnabled: true,
            valueChangeEvent: "input",
            maxHeight: "8em",
            onInput: e => {
                const shouldButtonBeDisabled = !this._isValuableTextEntered();
                this._toggleButtonDisableState(shouldButtonBeDisabled);
                this._triggerTypingStartAction(e);
                this._updateTypingEndTimeout()
            },
            onEnterKey: e => {
                var _e$event;
                if (!(null !== (_e$event = e.event) && void 0 !== _e$event && _e$event.shiftKey)) {
                    this._sendHandler(e)
                }
            }
        });
        this._textArea.registerKeyHandler("enter", (event => {
            if (!event.shiftKey && this._isValuableTextEntered()) {
                event.preventDefault()
            }
        }))
    }
    _renderButton() {
        const {
            activeStateEnabled: activeStateEnabled,
            focusStateEnabled: focusStateEnabled,
            hoverStateEnabled: hoverStateEnabled
        } = this.option();
        const $button = (0, _renderer.default)("<div>").addClass("dx-chat-messagebox-button").appendTo(this.element());
        this._button = this._createComponent($button, _button.default, {
            activeStateEnabled: activeStateEnabled,
            focusStateEnabled: focusStateEnabled,
            hoverStateEnabled: hoverStateEnabled,
            icon: "sendfilled",
            type: "default",
            stylingMode: "text",
            disabled: true,
            elementAttr: {
                "aria-label": _message.default.format("dxChat-sendButtonAriaLabel")
            },
            onClick: e => {
                this._sendHandler(e)
            }
        })
    }
    _createMessageEnteredAction() {
        this._messageEnteredAction = this._createActionByOption("onMessageEntered", {
            excludeValidators: ["disabled"]
        })
    }
    _createTypingStartAction() {
        this._typingStartAction = this._createActionByOption("onTypingStart", {
            excludeValidators: ["disabled"]
        })
    }
    _createTypingEndAction() {
        this._typingEndAction = this._createActionByOption("onTypingEnd", {
            excludeValidators: ["disabled"]
        })
    }
    _triggerTypingStartAction(e) {
        if (!this._typingEndTimeoutId) {
            var _this$_typingStartAct;
            null === (_this$_typingStartAct = this._typingStartAction) || void 0 === _this$_typingStartAct || _this$_typingStartAct.call(this, {
                event: e.event
            })
        }
    }
    _updateTypingEndTimeout() {
        clearTimeout(this._typingEndTimeoutId);
        this._typingEndTimeoutId = setTimeout((() => {
            var _this$_typingEndActio;
            null === (_this$_typingEndActio = this._typingEndAction) || void 0 === _this$_typingEndActio || _this$_typingEndActio.call(this);
            this._clearTypingEndTimeout()
        }), TYPING_END_DELAY)
    }
    _clearTypingEndTimeout() {
        clearTimeout(this._typingEndTimeoutId);
        this._typingEndTimeoutId = void 0
    }
    _sendHandler(e) {
        var _this$_typingEndActio2, _this$_messageEntered;
        if (!this._isValuableTextEntered()) {
            return
        }
        this._clearTypingEndTimeout();
        null === (_this$_typingEndActio2 = this._typingEndAction) || void 0 === _this$_typingEndActio2 || _this$_typingEndActio2.call(this);
        const {
            text: text
        } = this._textArea.option();
        this._textArea.reset();
        this._toggleButtonDisableState(true);
        null === (_this$_messageEntered = this._messageEnteredAction) || void 0 === _this$_messageEntered || _this$_messageEntered.call(this, {
            text: text,
            event: e.event
        })
    }
    _toggleButtonDisableState(state) {
        this._button.option("disabled", state)
    }
    _isValuableTextEntered() {
        const {
            text: text
        } = this._textArea.option();
        return !!(null !== text && void 0 !== text && text.trim())
    }
    _optionChanged(args) {
        const {
            name: name,
            value: value
        } = args;
        switch (name) {
            case "activeStateEnabled":
            case "focusStateEnabled":
            case "hoverStateEnabled":
                this._button.option(name, value);
                this._textArea.option(name, value);
                break;
            case "onMessageEntered":
                this._createMessageEnteredAction();
                break;
            case "onTypingStart":
                this._createTypingStartAction();
                break;
            case "onTypingEnd":
                this._createTypingEndAction();
                break;
            default:
                super._optionChanged(args)
        }
    }
    _clean() {
        this._clearTypingEndTimeout();
        super._clean()
    }
    updateInputAria(emptyViewId) {
        this._textArea.option({
            inputAttr: {
                "aria-labelledby": emptyViewId
            }
        })
    }
}
var _default = exports.default = MessageBox;
