/**
* DevExtreme (ui/chat.d.ts)
* Version: 24.2.2-beta
* Build date: Mon Nov 18 2024
*
* Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
* Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
*/
import {
    Format,
} from '../localization';

import {
    UserDefinedElement,
    DxElement,
} from '../core/element';

import {
    template,
} from '../core/templates/template';

import Widget, { WidgetOptions } from './widget/ui.widget';
import {
    EventInfo,
    NativeEventInfo,
    InitializedEventInfo,
    ChangedOptionInfo,
} from '../events/index';
import DataSource, { DataSourceLike } from '../data/data_source';

/**
 * 
 */
export type DisposingEvent = EventInfo<dxChat>;

/**
 * 
 */
export type InitializedEvent = InitializedEventInfo<dxChat>;

/**
 * 
 */
export type OptionChangedEvent = EventInfo<dxChat> & ChangedOptionInfo;

/**
 * 
 */
export type MessageEnteredEvent = NativeEventInfo<dxChat, KeyboardEvent | PointerEvent | MouseEvent | TouchEvent> & {
    /**
     * 
     */
    readonly message?: Message;
};

/**
 * 
 */
export type TypingStartEvent = NativeEventInfo<dxChat, UIEvent & { target: HTMLInputElement }> & {
    /**
     * 
     */
    readonly user?: User;
};

/**
 * 
 */
export type TypingEndEvent = EventInfo<dxChat> & {
    /**
     * 
     */
    readonly user?: User;
};

/**
 * 
 */
export type User = {
    /**
     * 
     */
    id?: number | string;
    /**
     * 
     */
    name?: string;
    /**
     * 
     */
    avatarUrl?: string;
    /**
     * 
     */
    avatarAlt?: string;
};

/**
 * 
 */
export type Alert = {
    /**
     * 
     */
    id?: number | string;
    /**
     * 
     */
    message?: string;
};

/**
 * 
 */
export type Message = {
    /**
     * 
     */
    id?: number | string;
    /**
     * 
     */
    timestamp?: Date | number | string;
    /**
     * 
     */
    author?: User;
    /**
     * 
     */
    text?: string;
};

export type MessageTemplateData = {
    readonly component: dxChat;
    readonly message?: Message;
};

/**
 * 
 * @deprecated 
 */
export interface dxChatOptions extends WidgetOptions<dxChat> {
    /**
     * 
     */
    activeStateEnabled?: boolean;
    /**
     * 
     */
    focusStateEnabled?: boolean;
    /**
     * 
     */
    hoverStateEnabled?: boolean;
    /**
     * 
     */
    user?: User;
    /**
     * 
     */
    items?: Array<Message>;
    /**
     * 
     */
    dataSource?: DataSourceLike<Message> | null;
    /**
     * 
     */
    dayHeaderFormat?: Format;
    /**
     * 
     */
    reloadOnChange?: boolean;
    /**
     * 
     */
    alerts?: Array<Alert>;
    /**
     * 
     */
    messageTemplate?: template | null | ((data: MessageTemplateData, messageBubbleElement: DxElement) => string | UserDefinedElement);
    /**
     * 
     */
    messageTimestampFormat?: Format;
    /**
     * 
     */
    typingUsers?: Array<User>;
    /**
     * 
     */
    showDayHeaders?: boolean;
    /**
     * 
     */
    showUserName?: boolean;
    /**
     * 
     */
    showAvatar?: boolean;
    /**
     * 
     */
    showMessageTimestamp?: boolean;
    /**
     * 
     */
    onMessageEntered?: ((e: MessageEnteredEvent) => void) | undefined;
    /**
     * 
     */
    onTypingStart?: ((e: TypingEndEvent) => void) | undefined ;
    /**
     * 
     */
    onTypingEnd?: ((e: TypingEndEvent) => void) | undefined;
}

/**
 * 
 */
export default class dxChat extends Widget<Properties> {
    /**
     * 
     */
    renderMessage(message: Message): void;

    getDataSource(): DataSource<Message>;
}

export type ExplicitTypes = {
    Properties: Properties;
    DisposingEvent: DisposingEvent;
    InitializedEvent: InitializedEvent;
    OptionChangedEvent: OptionChangedEvent;
};

export type Properties = dxChatOptions;


